@@ -10,39 +10,14 @@
 import gettext from 'sources/gettext';
 import url_for from 'sources/url_for';
 import React, { useEffect, useState, useRef } from 'react';
-import { Box, Grid, InputLabel } from '@material-ui/core';
-import { DefaultButton } from '../../../static/js/components/Buttons';
-import { makeStyles } from '@material-ui/styles';
-import { InputText } from '../../../static/js/components/FormComponents';
+import { Box, Grid, InputLabel } from '@mui/material';
+import { InputSQL } from '../../../static/js/components/FormComponents';
 import getApiInstance from '../../../static/js/api_instance';
-import { copyToClipboard } from '../../../static/js/clipboard';
-import { useDelayedCaller } from '../../../static/js/custom_hooks';
 import { usePgAdmin } from '../../../static/js/BrowserComponent';
 
-
-const useStyles = makeStyles((theme)=>({
-  container: {
-    padding: '16px',
-    height: '100%',
-    display: 'flex',
-    flexDirection: 'column',
-  },
-  copyBtn: {
-    marginRight: '1px',
-    float: 'right',
-    borderColor: theme.otherVars.borderColor,
-    fontSize: '13px',
-  },
-}));
-
 export default function AboutComponent() {
-  const classes = useStyles();
   const containerRef = useRef();
   const [aboutData, setAboutData] = useState([]);
-  const [copyText, setCopyText] = useState(gettext('Copy'));
-  const revertCopiedText = useDelayedCaller(()=>{
-    setCopyText(gettext('Copy'));
-  });
   const pgAdmin = usePgAdmin();
 
   useEffect(() => {
@@ -57,7 +32,7 @@ export default function AboutComponent() {
   }, []);
 
   return (
-    <Box className={classes.container} ref={containerRef}>
+    <Box sx={{ padding: '16px', height: '100%', display: 'flex',flexDirection: 'column'}} ref={containerRef}>
       <Grid container spacing={0} style={{marginBottom: '8px'}}>
         <Grid item lg={3} md={3} sm={3} xs={12}>
           <InputLabel style={{fontWeight: 'bold'}}>{gettext('Version')}</InputLabel>
@@ -74,6 +49,14 @@ export default function AboutComponent() {
           <InputLabel>{aboutData.app_mode}</InputLabel>
         </Grid>
       </Grid>
+      <Grid container spacing={0} style={{marginBottom: '8px'}}>
+        <Grid item lg={3} md={3} sm={3} xs={12}>
+          <InputLabel style={{fontWeight: 'bold'}}>{gettext('Commit:')}</InputLabel>
+        </Grid>
+        <Grid item lg={9} md={9} sm={9} xs={12}>
+          <InputLabel>{aboutData.commit_hash}</InputLabel>
+        </Grid>
+      </Grid>
       <Grid container spacing={0} style={{marginBottom: '8px'}}>
         <Grid item lg={3} md={3} sm={3} xs={12}>
           <InputLabel style={{fontWeight: 'bold'}}>{gettext('Current User')}</InputLabel>
@@ -82,13 +65,13 @@ export default function AboutComponent() {
           <InputLabel>{aboutData.current_user}</InputLabel>
         </Grid>
       </Grid>
-      { aboutData.nwjs &&
+      { aboutData.electron &&
         <Grid container spacing={0} style={{marginBottom: '8px'}}>
           <Grid item lg={3} md={3} sm={3} xs={12}>
-            <InputLabel style={{fontWeight: 'bold'}}>{gettext('NW.js Version')}</InputLabel>
+            <InputLabel style={{fontWeight: 'bold'}}>{gettext('Electron Version')}</InputLabel>
           </Grid>
           <Grid item lg={9} md={9} sm={9} xs={12}>
-            <InputLabel>{aboutData.nwjs}</InputLabel>
+            <InputLabel>{aboutData.electron}</InputLabel>
           </Grid>
         </Grid>
       }
@@ -131,21 +114,23 @@ export default function AboutComponent() {
         </Grid>
       }
       { aboutData.settings &&
-        <Box flexGrow="1" display="flex" flexDirection="column">
+        <Box flexGrow="1" display="flex" flexDirection="column" minHeight="0">
           <Box>
-            <span style={{fontWeight: 'bold'}}>{gettext('Server Configuration')}</span>
-            <DefaultButton className={classes.copyBtn} onClick={()=>{
-              copyToClipboard(aboutData.settings);
-              setCopyText(gettext('Copied!'));
-              revertCopiedText(1500);
-            }}>{copyText}</DefaultButton>
+            <InputLabel style={{fontWeight: 'bold'}}>{gettext('pgAdmin Server Configuration')}</InputLabel>
           </Box>
-          <Box flexGrow="1" paddingTop="1px">
-            <InputText style={{height: '100%'}} controlProps={{multiline: true}} inputStyle={{resize: 'none'}}
-              value={aboutData.settings}/>
+          <Box flexGrow="1" paddingTop="1px" minHeight="0">
+            <InputSQL value={aboutData.settings}
+              controlProps={{
+                readonly: true,
+                showCopyBtn: true,
+              }}
+              options={{
+                lineNumbers: false,
+                foldGutter: false
+              }} />
           </Box>
         </Box>
       }
     </Box>
   );
-}
\ No newline at end of file
+}
