@@ -4,5 +4,5 @@ SELECT x.extname from pg_catalog.pg_extension x
     WHERE x.oid = {{ eid }}::oid
 {% endif %}
 {% if name %}
-DROP EXTENSION {{ conn|qtIdent(name) }}{% if cascade %} CASCADE{% endif %};
+DROP EXTENSION IF EXISTS {{ conn|qtIdent(name) }}{% if cascade %} CASCADE{% endif %};
 {% endif %}
