@@ -9,21 +9,22 @@
 
 import gettext from 'sources/gettext';
 import BaseUISchema from 'sources/SchemaView/base_schema.ui';
-import DataGridViewWithHeaderForm from 'sources/helpers/DataGridViewWithHeaderForm';
+import { DataGridFormHeader } from 'sources/SchemaView/DataGridView';
 import { isEmptyString } from '../../../../../../../../static/js/validators';
 
 class TokenHeaderSchema extends BaseUISchema {
   constructor(tokenOptions) {
     super({
       token: undefined,
+      isNew: true,
     });
 
     this.tokenOptions = tokenOptions;
-    this.isNewFTSConf = true;
   }
 
-  addDisabled() {
-    return this.isNewFTSConf;
+  set isNewFTSConf(flag) {
+    if (this.state)
+      this.state.data = {...this.state.data, isNew: flag};
   }
 
   getNewData(data) {
@@ -34,10 +35,17 @@ class TokenHeaderSchema extends BaseUISchema {
   }
 
   get baseFields() {
-    let obj = this;
     return [{
-      id: 'token', label: gettext('Tokens'), type:'select', editable: false,
-      options: this.tokenOptions, disabled: function() { return obj.isNewFTSConf; }
+      id: 'token', label: gettext('Tokens'), deps: ['isNew'],
+      type: () => ({
+        type: 'select',
+        options: this.tokenOptions,
+      }),
+      disabled: function() {
+        return this.state ? this.state.data.isNew : true;
+      }
+    },{
+      id: 'isNew', visible: false, type: 'text', exclude: true,
     }];
   }
 }
@@ -153,12 +161,13 @@ export default class FTSConfigurationSchema extends BaseUISchema {
       }, {
         id: 'tokens', label: '', type: 'collection',
         group: gettext('Tokens'), mode: ['create','edit'],
-        editable: false, schema: this.tokColumnSchema,
+        schema: this.tokColumnSchema,
         headerSchema: this.tokHeaderSchema,
-        headerVisible: function() { return true;},
-        CustomControl: DataGridViewWithHeaderForm,
+        headerFormVisible: true,
+        GridHeader: DataGridFormHeader,
         uniqueCol : ['token'],
-        canAdd: true, canEdit: false, canDelete: true,
+        canAdd: (state, helpderProps) => (helpderProps.mode !== 'create'),
+        canDelete: true,
       }
     ];
   }
