@@ -2,7 +2,7 @@
 #
 # pgAdmin 4 - PostgreSQL Tools
 #
-# Copyright (C) 2013 - 2023, The pgAdmin Development Team
+# Copyright (C) 2013 - 2024, The pgAdmin Development Team
 # This software is released under the PostgreSQL Licence
 #
 ##########################################################################
@@ -26,7 +26,8 @@ class FtsTemplatePutTestCase(BaseTestGenerator):
 
     scenarios = [
         # Fetching default URL for FTS template node.
-        ('Fetch FTS template Node URL', dict(url='/browser/fts_template/obj/'))
+        ('Update FTS template Node',
+         dict(url='/browser/fts_template/obj/'))
     ]
 
     def setUp(self):
@@ -95,7 +96,7 @@ class FtsTemplatePutTestCase(BaseTestGenerator):
             data=json.dumps(data),
             follow_redirects=True)
 
-        self.assertEqual(negative_put_response.status_code, 500)
+        self.assertEqual(negative_put_response.status_code, 410)
 
     def tearDown(self):
         """This function delete the fts_template and disconnect the test
