@@ -4,6 +4,7 @@
 
 CREATE POLICY "test_select_policy_rls_$%{}[]()&*^!@""'`\/#"
     ON public.test_rls_policy
+    AS PERMISSIVE
     FOR SELECT
     TO public
-    USING ((name = ("current_user"())::text));
+    USING ((name = (CURRENT_USER)::text));
