@@ -1,8 +1,9 @@
-SELECT t.oid, t.typname AS name
+SELECT t.oid, t.typname AS name, des.description
 FROM pg_catalog.pg_type t
     LEFT OUTER JOIN pg_catalog.pg_type e ON e.oid=t.typelem
     LEFT OUTER JOIN pg_catalog.pg_class ct ON ct.oid=t.typrelid AND ct.relkind <> 'c'
     LEFT OUTER JOIN pg_catalog.pg_namespace nsp ON nsp.oid = t.typnamespace
+    LEFT OUTER JOIN pg_catalog.pg_description des ON (des.objoid=t.oid AND des.classoid='pg_type'::regclass)
 WHERE t.typtype != 'd' AND t.typname NOT LIKE E'\\_%' AND t.typnamespace = {{scid}}::oid
 {% if tid %}
     AND t.oid = {{tid}}::oid
@@ -10,4 +11,8 @@ WHERE t.typtype != 'd' AND t.typname NOT LIKE E'\\_%' AND t.typnamespace = {{sci
 {% if not show_system_objects %}
     AND ct.oid is NULL
 {% endif %}
+{% if schema_diff %}
+    AND CASE WHEN (SELECT COUNT(*) FROM pg_catalog.pg_depend
+        WHERE objid = t.oid AND deptype = 'e') > 0 THEN FALSE ELSE TRUE END
+{% endif %}
 ORDER BY t.typname;
