@@ -129,7 +129,10 @@ export default class SubscriptionSchema extends BaseUISchema{
       id: 'port', label: gettext('Port'), type: 'int', group: gettext('Connection'),
       mode: ['properties', 'edit', 'create'], min: 1, max: 65535,
       depChange: (state)=>{
-        if(obj.origData.port != state.port && !obj.isNew(state) && state.connected){
+        if(
+          obj.origData.port != state.port && !obj.isNew(state) &&
+          state.connected
+        ) {
           obj.informText = gettext(
             'To apply changes to the connection configuration, please disconnect from the server and then reconnect.'
           );
@@ -145,7 +148,10 @@ export default class SubscriptionSchema extends BaseUISchema{
       id: 'username', label: gettext('Username'), type: 'text', group: gettext('Connection'),
       mode: ['properties', 'edit', 'create'],
       depChange: (state)=>{
-        if(obj.origData.username != state.username && !obj.isNew(state) && state.connected){
+        if(
+          obj.origData.username != state.username && !obj.isNew(state) &&
+          state.connected
+        ) {
           obj.informText = gettext(
             'To apply changes to the connection configuration, please disconnect from the server and then reconnect.'
           );
