@@ -165,6 +165,8 @@ export default class RoleSchema extends BaseUISchema {
         disabled: obj.readOnly,
         mode: ['edit', 'create'], cell: 'text',
         type: 'collection',
+        canDelete: (state) => !obj.readOnly(state),
+        canDeleteRow: true,
         schema: obj.membershipSchema,
         helpMessage: obj.isReadOnly ? gettext('Select the checkbox for roles to include WITH ADMIN OPTION.') : gettext('Roles shown with a check mark have the WITH ADMIN OPTION set.'),
       },
@@ -185,7 +187,9 @@ export default class RoleSchema extends BaseUISchema {
         type: 'collection',
         schema: obj.membershipSchema,
         disabled: obj.readOnly,
-        helpMessage: obj.isReadOnly ? gettext('Select the checkbox for roles to include WITH ADMIN OPTION.') : gettext('Roles shown with a check mark have the WITH ADMIN OPTION set.') ,
+        canDelete: (state) => !obj.readOnly(state),
+        canDeleteRow: true,
+        helpMessage: obj.isReadOnly ? gettext('Select the checkbox for roles to include WITH ADMIN OPTION.') : gettext('Roles shown with a check mark have the WITH ADMIN OPTION set.'),
       },
       {
         id: 'rolmembers', label: gettext('Members'), group: gettext('Membership'),
