@@ -20,11 +20,13 @@ import getApiInstance from '../../../../static/js/api_instance';
 import CloseSharpIcon from '@mui/icons-material/CloseSharp';
 import HelpIcon from '@mui/icons-material/HelpRounded';
 import SaveSharpIcon from '@mui/icons-material/SaveSharp';
+import SettingsBackupRestoreIcon from'@mui/icons-material/SettingsBackupRestore';
 import pgAdmin from 'sources/pgadmin';
 import { DefaultButton, PgIconButton, PrimaryButton } from '../../../../static/js/components/Buttons';
 import BaseUISchema from 'sources/SchemaView/base_schema.ui';
 import { getBinaryPathSchema } from '../../../../browser/server_groups/servers/static/js/binary_path.ui';
 import usePreferences from '../store';
+import { getBrowser } from '../../../../static/js/utils';
 
 
 const StyledBox = styled(Box)(({theme}) => ({
@@ -86,6 +88,7 @@ const StyledBox = styled(Box)(({theme}) => ({
   },
 }));
 
+
 class PreferencesSchema extends BaseUISchema {
   constructor(initValues = {}, schemaFields = []) {
     super({
@@ -99,8 +102,8 @@ class PreferencesSchema extends BaseUISchema {
     return 'id';
   }
 
-  setSelectedCategory(category) {
-    this.category = category;
+  categoryUpdated() {
+    this.state?.validate(this.sessData);
   }
 
   get baseFields() {
@@ -108,8 +111,19 @@ class PreferencesSchema extends BaseUISchema {
   }
 }
 
+async function reloadPgAdmin() {
+  let {name: browser} = getBrowser();
+  if(browser == 'Electron') {
+    await window.electronUI.log('test');
+    await window.electronUI.reloadApp();
+  } else {
+    location.reload();
+  }
+}
 
-function RightPanel({ schema, ...props }) {
+
+function RightPanel({ schema, refreshKey, ...props }) {
+  const schemaViewRef = React.useRef(null);
   let initData = () => new Promise((resolve, reject) => {
     try {
       resolve(props.initValues);
@@ -117,20 +131,31 @@ function RightPanel({ schema, ...props }) {
       reject(error instanceof Error ? error : Error(gettext('Something went wrong')));
     }
   });
+  useEffect(() => {
+    const timeID = setTimeout(() => {
+      const focusableElement = schemaViewRef.current?.querySelector(
+        'button, a, input, select, textarea, [tabindex]:not([tabindex="-1"])'
+      );
+      if (focusableElement) focusableElement.focus();
+    }, 50);
+    return () => clearTimeout(timeID);
+  }, [refreshKey]);
 
   return (
-    <SchemaView
-      formType={'dialog'}
-      getInitData={initData}
-      viewHelperProps={{ mode: 'edit' }}
-      schema={schema}
-      showFooter={false}
-      isTabView={false}
-      formClassName='PreferencesComponent-preferencesContainerBackground'
-      onDataChange={(isChanged, changedData) => {
-        props.onDataChange(changedData);
-      }}
-    />
+    <div ref={schemaViewRef}>
+      <SchemaView
+        formType={'dialog'}
+        getInitData={initData}
+        viewHelperProps={{ mode: 'edit' }}
+        schema={schema}
+        showFooter={false}
+        isTabView={false}
+        formClassName='PreferencesComponent-preferencesContainerBackground'
+        onDataChange={(isChanged, changedData) => {
+          props.onDataChange(changedData);
+        }}
+      />
+    </div>
   );
 }
 
@@ -143,6 +168,7 @@ RightPanel.propTypes = {
 
 export default function PreferencesComponent({ ...props }) {
 
+  const [refreshKey, setRefreshKey] = React.useState(0);
   const [disableSave, setDisableSave] = React.useState(true);
   const prefSchema = React.useRef(new PreferencesSchema({}, []));
   const prefChangedData = React.useRef({});
@@ -213,12 +239,17 @@ export default function PreferencesComponent({ ...props }) {
       setPrefTreeData(preferencesTreeData);
       setInitValues(preferencesValues);
       // set Preferences schema
-      prefSchema.current = new PreferencesSchema(preferencesValues, preferencesData);
+      prefSchema.current = new PreferencesSchema(
+        preferencesValues, preferencesData,
+      );
     }).catch((err) => {
       pgAdmin.Browser.notifier.alert(err);
     });
   }, []);
-  function setPreferences(node, subNode, nodeData, preferencesValues, preferencesData) {
+
+  function setPreferences(
+    node, subNode, nodeData, preferencesValues, preferencesData
+  ) {
     let addBinaryPathNote = false;
     subNode.preferences.forEach((element) => {
       let note = '';
@@ -334,9 +365,10 @@ export default function PreferencesComponent({ ...props }) {
       preferencesData.push(
         {
           id: _.uniqueId('note') + subNode.id,
-          type: 'note', text: note,
+          type: 'note',
+          text: note,
+          'parentId': nodeData['id'],
           visible: false,
-          'parentId': nodeData['id']
         },
       );
     }
@@ -350,28 +382,25 @@ export default function PreferencesComponent({ ...props }) {
   }
 
   useEffect(() => {
-    let initTreeTimeout = null;
     let firstElement = null;
     // Listen selected preferences tree node event and show the appropriate components in right panel.
     pgAdmin.Browser.Events.on('preferences:tree:selected', (event, item) => {
       if (item.type == FileType.File) {
-        prefSchema.current.setSelectedCategory(item._metadata.data.name);
         prefSchema.current.schemaFields.forEach((field) => {
-          field.visible = field.parentId === item._metadata.data.id && !field?.hidden ;
+          field.visible = field.parentId === item._metadata.data.id &&
+            !field?.hidden ;
+
           if(field.visible && _.isNull(firstElement)) {
             firstElement = field;
           }
-          field.labelTooltip = item._parent._metadata.data.name.toLowerCase() + ':' + item._metadata.data.name + ':' + field.name;
+
+          field.labelTooltip =
+            item._parent._metadata.data.name.toLowerCase() + ':' +
+            item._metadata.data.name + ':' + field.name;
         });
-        setLoadTree(crypto.getRandomValues(new Uint16Array(1)));
-        initTreeTimeout = setTimeout(() => {
-          prefTreeInit.current = true;
-          if(firstElement) {
-            //set focus on first element on right side panel.
-            document.getElementsByName(firstElement.id.toString())[0].focus();
-            firstElement = '';
-          }
-        }, 10);
+        prefSchema.current.categoryUpdated(item._metadata.data.id);
+        setLoadTree(Date.now());
+        setRefreshKey(Date.now());
       }
       else {
         selectChildNode(item, prefTreeInit);
@@ -385,10 +414,6 @@ export default function PreferencesComponent({ ...props }) {
 
     // Listen added preferences tree node event to expand the newly added node on tree load.
     pgAdmin.Browser.Events.on('preferences:tree:added', addPrefTreeNode);
-    /* Clear the initTreeTimeout timeout if unmounted */
-    return () => {
-      clearTimeout(initTreeTimeout);
-    };
   }, []);
 
   function addPrefTreeNode(event, item) {
@@ -569,7 +594,7 @@ export default function PreferencesComponent({ ...props }) {
           gettext('A page refresh is required to apply the theme. Do you wish to refresh the page now?'),
           function () {
             /* If user clicks Yes */
-            location.reload();
+            reloadPgAdmin();
             return true;
           },
           function () { props.closeModal();},
@@ -589,6 +614,64 @@ export default function PreferencesComponent({ ...props }) {
     window.open(url_for('help.static', { 'filename': 'preferences.html' }), 'pgadmin_help');
   };
 
+  const reset = () => {
+    pgAdmin.Browser.notifier.confirm(
+      gettext('Reset all preferences'),
+      `${gettext('All preferences will be reset to their default values.')}<br><br>${gettext('Do you want to proceed?')}<br><br>
+       ${gettext('Note:')}<br> <ul style="padding-left:20px"><li style="list-style-type:disc">${gettext('The object explorer tree will be refreshed automatically to reflect the changes.')}</li>
+       <li style="list-style-type:disc">${gettext('If the application language changes, a reload of the application will be required. You can choose to reload later at your convenience.')}</li></ul>`,
+      function () {},
+      function () {},
+      '',
+      'Cancel',
+      function (closeModal) {
+        return [
+          {
+            type: 'default',
+            icon: <SaveSharpIcon />,
+            label: gettext('Save & Reload'),
+            onclick: () => {
+              resetPrefsToDefault(true);
+              closeModal();
+            }
+          }, {
+            type: 'primary',
+            icon: <SaveSharpIcon />,
+            label: gettext('Save & Reload Later'),
+            onclick: () => {
+              resetPrefsToDefault(false);
+              closeModal();
+            }
+          }
+        ];
+      }
+    );
+  };
+
+  const resetPrefsToDefault = (refresh = false) => {
+    api({
+      url: url_for('preferences.index'),
+      method: 'DELETE'
+    }).then(()=>{
+      if (refresh){
+        reloadPgAdmin();
+        return true;
+      }
+      preferencesStore.cache();
+      pgAdmin.Browser.tree.destroy().then(
+        () => {
+          pgAdmin.Browser.Events.trigger(
+            'pgadmin-browser:tree:destroyed', undefined, undefined
+          );
+          return true;
+        }
+      );
+      props.closeModal();
+    }).catch((err) => {
+      pgAdmin.Browser.notifier.alert(err.response.data);
+    });
+  };
+
   return (
     <StyledBox height={'100%'}>
       <Box className='PreferencesComponent-root'>
@@ -596,29 +679,54 @@ export default function PreferencesComponent({ ...props }) {
           <Box className='PreferencesComponent-treeContainer' >
             <Box className='PreferencesComponent-tree' id={'treeContainer'} tabIndex={0}>
               {
-                useMemo(() => (prefTreeData && props.renderTree(prefTreeData)), [prefTreeData])
+                useMemo(
+                  () => (prefTreeData && props.renderTree(prefTreeData)),
+                  [prefTreeData]
+                )
               }
             </Box>
           </Box>
           <Box className='PreferencesComponent-preferencesContainer'>
             {
               prefSchema.current && loadTree > 0 &&
-                <RightPanel schema={prefSchema.current} initValues={initValues} onDataChange={(changedData) => {
-                  Object.keys(changedData).length > 0 ? setDisableSave(false) : setDisableSave(true);
-                  prefChangedData.current = changedData;
-                }}></RightPanel>
+                <RightPanel
+                  schema={prefSchema.current} initValues={initValues}
+                  refreshKey={refreshKey}
+                  onDataChange={(changedData) => {
+                    Object.keys(changedData).length > 0 ?
+                      setDisableSave(false) : setDisableSave(true);
+                    prefChangedData.current = changedData;
+                  }}
+                ></RightPanel>
             }
           </Box>
         </Box>
         <Box className='PreferencesComponent-footer'>
           <Box>
-            <PgIconButton data-test="dialog-help" onClick={onDialogHelp} icon={<HelpIcon />} title={gettext('Help for this dialog.')} />
+            <PgIconButton
+              data-test="dialog-help" onClick={onDialogHelp}
+              icon={<HelpIcon />} title={gettext('Help for this dialog.')}
+            />
           </Box>
           <Box className='PreferencesComponent-actionBtn' marginLeft="auto">
-            <DefaultButton className='PreferencesComponent-buttonMargin' onClick={() => { props.closeModal();}} startIcon={<CloseSharpIcon onClick={() => { props.closeModal();}} />}>
+            <DefaultButton className='PreferencesComponent-buttonMargin'
+              onClick={reset} startIcon={<SettingsBackupRestoreIcon />}>
+              {gettext('Reset all preferences')}
+            </DefaultButton>
+            <DefaultButton className='PreferencesComponent-buttonMargin'
+              onClick={() => { props.closeModal();}}
+              startIcon={
+                <CloseSharpIcon onClick={() => { props.closeModal();}} />
+              }>
               {gettext('Cancel')}
             </DefaultButton>
-            <PrimaryButton className='PreferencesComponent-buttonMargin' startIcon={<SaveSharpIcon />} disabled={disableSave} onClick={() => { savePreferences(prefChangedData, initValues); }}>
+            <PrimaryButton
+              className='PreferencesComponent-buttonMargin'
+              startIcon={<SaveSharpIcon />}
+              disabled={disableSave}
+              onClick={() => {
+                savePreferences(prefChangedData, initValues);
+              }}>
               {gettext('Save')}
             </PrimaryButton>
           </Box>
