@@ -6,24 +6,24 @@
 // This software is released under the PostgreSQL Licence
 //
 //////////////////////////////////////////////////////////////
-import { Box, Tab, Tabs } from '@material-ui/core';
+import { Box, Tab, Tabs } from '@mui/material';
+import { styled } from '@mui/material/styles';
 import React from 'react';
 import _ from 'lodash';
 import Graphical from './Graphical';
 import TabPanel from '../components/TabPanel';
 import gettext  from 'sources/gettext';
 import ImageMapper from './ImageMapper';
-import { makeStyles } from '@material-ui/styles';
 import Analysis from './Analysis';
 import ExplainStatistics from './ExplainStatistics';
 import PropTypes from 'prop-types';
 import EmptyPanelMessage from '../components/EmptyPanelMessage';
 
-const useStyles = makeStyles((theme)=>({
-  tabPanel: {
-    padding: 0,
-    backgroundColor: theme.palette.background.default,
-  },
+const StyledBox = styled(Box)(({theme}) => ({
+  '& .Explain-tabPanel': {
+    padding: '0 !important',
+    backgroundColor: theme.palette.background.default + ' !important',
+  }
 }));
 
 // Some predefined constants used to calculate image location and its border
@@ -466,7 +466,7 @@ function parsePlanData(data, ctx) {
 }
 
 export default function Explain({plans=[]}) {
-  const classes = useStyles();
+
   const [tabValue, setTabValue] = React.useState(0);
 
   let ctx = React.useRef({});
@@ -488,12 +488,14 @@ export default function Explain({plans=[]}) {
   }, [plans]);
 
   if(_.isEmpty(plans)) {
-    return <Box height="100%" display="flex" flexDirection="column">
-      <EmptyPanelMessage text={gettext('Use Explain/Explain analyze button to generate the plan for a query. Alternatively, you can also execute "EXPLAIN (FORMAT JSON) [QUERY]".')} />
-    </Box>;
+    return (
+      <StyledBox height="100%" display="flex" flexDirection="column">
+        <EmptyPanelMessage text={gettext('Use Explain/Explain analyze button to generate the plan for a query. Alternatively, you can also execute "EXPLAIN (FORMAT JSON) [QUERY]".')} />
+      </StyledBox>
+    );
   }
   return (
-    <Box height="100%" display="flex" flexDirection="column">
+    <StyledBox height="100%" display="flex" flexDirection="column">
       <Box>
         <Tabs
           value={tabValue}
@@ -510,16 +512,16 @@ export default function Explain({plans=[]}) {
           <Tab label="Statistics" />
         </Tabs>
       </Box>
-      <TabPanel value={tabValue} index={0} classNameRoot={classes.tabPanel}>
+      <TabPanel value={tabValue} index={0} classNameRoot='Explain-tabPanel'>
         <Graphical planData={planData} ctx={ctx.current}/>
       </TabPanel>
-      <TabPanel value={tabValue} index={1} classNameRoot={classes.tabPanel}>
+      <TabPanel value={tabValue} index={1} classNameRoot='Explain-tabPanel'>
         <Analysis explainTable={ctx.current.explainTable} />
       </TabPanel>
-      <TabPanel value={tabValue} index={2} classNameRoot={classes.tabPanel}>
+      <TabPanel value={tabValue} index={2} classNameRoot='Explain-tabPanel'>
         <ExplainStatistics explainTable={ctx.current.explainTable} />
       </TabPanel>
-    </Box>
+    </StyledBox>
   );
 }
 
