@@ -7,52 +7,51 @@
 //
 //////////////////////////////////////////////////////////////
 
-import { CircularProgress, Box, Typography, makeStyles } from '@material-ui/core';
+import { CircularProgress, Box, Typography } from '@mui/material';
+import { styled } from '@mui/material/styles';
 import React from 'react';
 import PropTypes from 'prop-types';
 
-const useStyles = makeStyles((theme)=>({
-  root: {
-    position: 'absolute',
-    top: 0,
-    bottom: 0,
-    left: 0,
-    right: 0,
-    backgroundColor: theme.otherVars.loader.backgroundColor,
-    color: theme.otherVars.loader.color,
-    zIndex: 1000,
-    display: 'flex',
-  },
-  loaderRoot: {
+const StyledBox = styled(Box)(({theme}) => ({
+  position: 'absolute',
+  top: 0,
+  bottom: 0,
+  left: 0,
+  right: 0,
+  backgroundColor: theme.otherVars.loader.backgroundColor,
+  color: theme.otherVars.loader.color,
+  zIndex: 1000,
+  display: 'flex',
+  '& .Loader-loaderBody': {
     color: theme.otherVars.loader.color,
     display: 'flex',
     alignItems: 'center',
     margin: 'auto',
     '.MuiTypography-root': {
       marginLeft: theme.spacing(1),
+    },
+    '& .Loader-icon': {
+      color: theme.otherVars.loader.color,
+    },
+    '& .Loader-message': {
+      marginLeft: '0.5rem',
+      fontSize: '16px',
     }
   },
-  loader: {
-    color: theme.otherVars.loader.color,
-  },
-  message: {
-    marginLeft: '0.5rem',
-    fontSize: '16px',
-  }
 }));
 
 export default function Loader({message, style, autoEllipsis=false, ...props}) {
-  const classes = useStyles();
+
   if(!message) {
     return <></>;
   }
   return (
-    <Box className={classes.root} style={style} data-label="loader" {...props}>
-      <Box className={classes.loaderRoot}>
-        <CircularProgress className={classes.loader} />
-        <Typography className={classes.message}>{message}{autoEllipsis ? '...':''}</Typography>
+    <StyledBox style={style} data-label="loader" {...props}>
+      <Box className='Loader-loaderBody'>
+        <CircularProgress className='Loader-icon' />
+        <Typography className='Loader-message'>{message}{autoEllipsis ? '...':''}</Typography>
       </Box>
-    </Box>
+    </StyledBox>
   );
 }
 
