@@ -9,36 +9,13 @@
 
 import gettext from 'sources/gettext';
 import _ from 'lodash';
-import { FormGroup, makeStyles, Grid, Typography } from '@material-ui/core';
+import { FormGroup, Grid, Typography } from '@mui/material';
 import React from 'react';
 import { InputText } from './FormComponents';
 import PropTypes from 'prop-types';
 
-const useStyles = makeStyles(() => ({
-  formControlLabel: {
-    padding: '3px',
-  },
-  formInput: {
-    marginLeft: '5px'
-  },
-  formCheckboxControl: {
-    padding: '3px',
-    border: '1px solid',
-    borderRadius: '0.25rem',
-  },
-  formGroup: {
-    padding: '5px'
-  },
-  contentTextAlign: {
-    textAlign: 'center'
-  },
-  contentStyle: {
-    paddingLeft: 10,
-  }
-}));
 
 export default function QueryThresholds({ value, onChange }) {
-  const classes = useStyles();
   const warningCid = _.uniqueId('c');
   const warninghelpid = `h${warningCid}`;
   const alertCid = _.uniqueId('c');
@@ -69,13 +46,13 @@ export default function QueryThresholds({ value, onChange }) {
         <Grid item lg={2} md={2} sm={2} xs={12}>
           <InputText cid={warningCid} helpid={warninghelpid} type='numeric' value={value?.warning} onChange={onWarningChange} />
         </Grid>
-        <Grid item lg={2} md={2} sm={2} xs={12} className={classes.contentTextAlign}>
+        <Grid item lg={2} md={2} sm={2} xs={12} sx={{ textAlign: 'center' }}>
           <Typography>{gettext('Alert')}</Typography>
         </Grid>
         <Grid item lg={2} md={2} sm={2} xs={12}>
           <InputText cid={alertCid} helpid={alerthelpid} type='numeric' value={value?.alert} onChange={onAlertChange} />
         </Grid>
-        <Grid item lg={4} md={4} sm={4} xs={12} className={classes.contentStyle}>
+        <Grid item lg={4} md={4} sm={4} xs={12} sx={{paddingLeft: 10 }}>
           <Typography>{gettext('(in minutes)')}</Typography>
         </Grid>
       </Grid>
