@@ -16,12 +16,11 @@ import copy
 
 from flask import render_template, request, current_app
 from flask_babel import gettext
-from flask_security import login_required
+from pgadmin.user_login_check import pga_login_required
 from werkzeug.user_agent import UserAgent
 
 from pgadmin.utils import PgAdminModule, \
-    SHORTCUT_FIELDS as shortcut_fields, \
-    ACCESSKEY_FIELDS as accesskey_fields
+    SHORTCUT_FIELDS as shortcut_fields
 from pgadmin.utils.ajax import bad_request
 from pgadmin.utils.ajax import make_json_response, \
     internal_server_error, gone
@@ -45,6 +44,7 @@ ASYNC_OK = 1
 DEBUGGER_SQL_PATH = 'debugger/sql'
 DEBUGGER_SQL_V1_PATH = 'debugger/sql/v1'
 DEBUGGER_SQL_V3_PATH = 'debugger/sql/v3'
+SET_SEARCH_PATH = "SET search_path={0};"
 
 
 class DebuggerModule(PgAdminModule):
@@ -58,80 +58,98 @@ class DebuggerModule(PgAdminModule):
     def register_preferences(self):
         self.preference.register(
             'keyboard_shortcuts', 'btn_start',
-            gettext('Accesskey (Continue/Start)'), 'keyboardshortcut',
+            gettext('Continue/Start'), 'keyboardshortcut',
             {
+                'alt': True,
+                'shift': True,
+                'control': False,
                 'key': {
                     'key_code': 67,
                     'char': 'c'
                 }
             },
             category_label=PREF_LABEL_KEYBOARD_SHORTCUTS,
-            fields=accesskey_fields
+            fields=shortcut_fields
         )
 
         self.preference.register(
             'keyboard_shortcuts', 'btn_stop',
-            gettext('Accesskey (Stop)'), 'keyboardshortcut',
+            gettext('Stop'), 'keyboardshortcut',
             {
+                'alt': True,
+                'shift': True,
+                'control': False,
                 'key': {
                     'key_code': 83,
                     'char': 's'
                 }
             },
             category_label=PREF_LABEL_KEYBOARD_SHORTCUTS,
-            fields=accesskey_fields
+            fields=shortcut_fields
         )
 
         self.preference.register(
             'keyboard_shortcuts', 'btn_step_into',
-            gettext('Accesskey (Step into)'), 'keyboardshortcut',
+            gettext('Step into'), 'keyboardshortcut',
             {
+                'alt': True,
+                'shift': True,
+                'control': False,
                 'key': {
                     'key_code': 73,
                     'char': 'i'
                 }
             },
             category_label=PREF_LABEL_KEYBOARD_SHORTCUTS,
-            fields=accesskey_fields
+            fields=shortcut_fields
         )
 
         self.preference.register(
             'keyboard_shortcuts', 'btn_step_over',
-            gettext('Accesskey (Step over)'), 'keyboardshortcut',
+            gettext('Step over'), 'keyboardshortcut',
             {
+                'alt': True,
+                'shift': True,
+                'control': False,
                 'key': {
                     'key_code': 79,
                     'char': 'o'
                 }
             },
             category_label=PREF_LABEL_KEYBOARD_SHORTCUTS,
-            fields=accesskey_fields
+            fields=shortcut_fields
         )
 
         self.preference.register(
             'keyboard_shortcuts', 'btn_toggle_breakpoint',
-            gettext('Accesskey (Toggle breakpoint)'), 'keyboardshortcut',
+            gettext('Toggle breakpoint'), 'keyboardshortcut',
             {
+                'alt': True,
+                'shift': True,
+                'control': False,
                 'key': {
                     'key_code': 84,
                     'char': 't'
                 }
             },
             category_label=PREF_LABEL_KEYBOARD_SHORTCUTS,
-            fields=accesskey_fields
+            fields=shortcut_fields
         )
 
         self.preference.register(
             'keyboard_shortcuts', 'btn_clear_breakpoints',
-            gettext('Accesskey (Clear all breakpoints)'), 'keyboardshortcut',
+            gettext('Clear all breakpoints'), 'keyboardshortcut',
             {
+                'alt': True,
+                'shift': True,
+                'control': False,
                 'key': {
                     'key_code': 88,
                     'char': 'x'
                 }
             },
             category_label=PREF_LABEL_KEYBOARD_SHORTCUTS,
-            fields=accesskey_fields
+            fields=shortcut_fields
         )
 
         self.preference.register(
@@ -237,7 +255,7 @@ blueprint = DebuggerModule(MODULE_NAME, __name__)
 
 
 @blueprint.route("/", endpoint='index')
-@login_required
+@pga_login_required
 def index():
     return bad_request(
         errormsg=gettext("This URL cannot be called directly.")
@@ -245,7 +263,7 @@ def index():
 
 
 def execute_dict_search_path(conn, sql, search_path):
-    sql_search = "SET search_path={0};".format(search_path)
+    sql_search = SET_SEARCH_PATH.format(search_path)
     status, res = conn.execute_void(sql_search)
 
     if not status:
@@ -258,7 +276,7 @@ def execute_dict_search_path(conn, sql, search_path):
 
 
 def execute_async_search_path(conn, sql, search_path):
-    sql_search = "SET search_path={0};".format(search_path)
+    sql_search = SET_SEARCH_PATH.format(search_path)
     status, res = conn.execute_void(sql_search)
 
     if not status:
@@ -350,7 +368,7 @@ def check_node_type(node_type, fid, trid, conn, ppas_server,
     '/init/<node_type>/<int:sid>/<int:did>/<int:scid>/<int:fid>/<int:trid>',
     methods=['GET'], endpoint='init_for_trigger'
 )
-@login_required
+@pga_login_required
 def init_function(node_type, sid, did, scid, fid, trid=None):
     """
     init_function(node_type, sid, did, scid, fid, trid)
@@ -557,7 +575,7 @@ def check_user_ip_req(r_set, data):
 
 
 @blueprint.route('/direct/<int:trans_id>', methods=['GET'], endpoint='direct')
-@login_required
+@pga_login_required
 def direct_new(trans_id):
     de_inst = DebuggerInstance(trans_id)
 
@@ -662,7 +680,7 @@ def get_debugger_version(conn, search_path):
     :return:
     """
     debugger_version = 0
-    status, res = conn.execute_void("SET search_path={0};".format(search_path))
+    status, res = conn.execute_void(SET_SEARCH_PATH.format(search_path))
 
     if not status:
         return False, internal_server_error(errormsg=res)
@@ -769,7 +787,7 @@ def get_search_path(conn):
     methods=['POST'],
     endpoint='initialize_target_for_trigger'
 )
-@login_required
+@pga_login_required
 def initialize_target(debug_type, trans_id, sid, did,
                       scid, func_id, tri_id=None):
     """
@@ -894,7 +912,7 @@ def close(trans_id):
 @blueprint.route(
     '/restart/<int:trans_id>', methods=['GET'], endpoint='restart'
 )
-@login_required
+@pga_login_required
 def restart_debugging(trans_id):
     """
     restart_debugging(trans_id)
@@ -959,7 +977,7 @@ def restart_debugging(trans_id):
     '/start_listener/<int:trans_id>', methods=['POST'],
     endpoint='start_listener'
 )
-@login_required
+@pga_login_required
 def start_debugger_listener(trans_id):
     """
     start_debugger_listener(trans_id)
@@ -1203,7 +1221,7 @@ def get_debugger_arg_val(val_list):
     '/execute_query/<int:trans_id>/<query_type>', methods=['GET'],
     endpoint='execute_query'
 )
-@login_required
+@pga_login_required
 def execute_debugger_query(trans_id, query_type):
     """
     execute_debugger_query(trans_id, query_type)
@@ -1290,7 +1308,7 @@ def execute_debugger_query(trans_id, query_type):
 @blueprint.route(
     '/messages/<int:trans_id>/', methods=["GET"], endpoint='messages'
 )
-@login_required
+@pga_login_required
 def messages(trans_id):
     """
     messages(trans_id)
@@ -1348,7 +1366,7 @@ def messages(trans_id):
     '/start_execution/<int:trans_id>/<int:port_num>', methods=['GET'],
     endpoint='start_execution'
 )
-@login_required
+@pga_login_required
 def start_execution(trans_id, port_num):
     """
     start_execution(trans_id, port_num)
@@ -1424,7 +1442,7 @@ def start_execution(trans_id, port_num):
     '/set_breakpoint/<int:trans_id>/<int:line_no>/<int:set_type>',
     methods=['GET'], endpoint='set_breakpoint'
 )
-@login_required
+@pga_login_required
 def set_clear_breakpoint(trans_id, line_no, set_type):
     """
     set_clear_breakpoint(trans_id, line_no, set_type)
@@ -1525,7 +1543,7 @@ def get_debugger_template_path(de_inst):
     '/clear_all_breakpoint/<int:trans_id>', methods=['POST'],
     endpoint='clear_all_breakpoint'
 )
-@login_required
+@pga_login_required
 def clear_all_breakpoint(trans_id):
     """
     clear_all_breakpoint(trans_id)
@@ -1597,7 +1615,7 @@ def clear_all_breakpoint(trans_id):
     '/deposit_value/<int:trans_id>', methods=['POST'],
     endpoint='deposit_value'
 )
-@login_required
+@pga_login_required
 def deposit_parameter_value(trans_id):
     """
     deposit_parameter_value(trans_id)
@@ -1671,7 +1689,7 @@ def deposit_parameter_value(trans_id):
     '/select_frame/<int:trans_id>/<int:frame_id>', methods=['GET'],
     endpoint='select_frame'
 )
-@login_required
+@pga_login_required
 def select_frame(trans_id, frame_id):
     """
     select_frame(trans_id, frame_id)
@@ -1733,7 +1751,7 @@ def select_frame(trans_id, frame_id):
     '/get_arguments/<int:sid>/<int:did>/<int:scid>/<int:func_id>',
     methods=['GET'], endpoint='get_arguments'
 )
-@login_required
+@pga_login_required
 def get_arguments_sqlite(sid, did, scid, func_id):
     """
     get_arguments_sqlite(sid, did, scid, func_id)
@@ -1818,7 +1836,7 @@ def get_array_string(data, i):
     '/set_arguments/<int:sid>/<int:did>/<int:scid>/<int:func_id>',
     methods=['POST'], endpoint='set_arguments'
 )
-@login_required
+@pga_login_required
 def set_arguments_sqlite(sid, did, scid, func_id):
     """
     set_arguments_sqlite(sid, did, scid, func_id)
@@ -1907,7 +1925,7 @@ def set_arguments_sqlite(sid, did, scid, func_id):
     '/clear_arguments/<int:sid>/<int:did>/<int:scid>/<int:func_id>',
     methods=['POST'], endpoint='clear_arguments'
 )
-@login_required
+@pga_login_required
 def clear_arguments_sqlite(sid, did, scid, func_id):
     """
     clear_arguments_sqlite(sid, did, scid, func_id)
@@ -2052,7 +2070,7 @@ def check_result(result, conn, statusmsg):
     '/poll_end_execution_result/<int:trans_id>/',
     methods=["GET"], endpoint='poll_end_execution_result'
 )
-@login_required
+@pga_login_required
 def poll_end_execution_result(trans_id):
     """
     poll_end_execution_result(trans_id)
@@ -2128,7 +2146,7 @@ def poll_end_execution_result(trans_id):
 @blueprint.route(
     '/poll_result/<int:trans_id>/', methods=["GET"], endpoint='poll_result'
 )
-@login_required
+@pga_login_required
 def poll_result(trans_id):
     """
     poll_result(trans_id)
