@@ -7,7 +7,7 @@
 //
 //////////////////////////////////////////////////////////////
 
-import { Box } from '@material-ui/core';
+import { Box } from '@mui/material';
 import React, { useEffect, useRef, useState } from 'react';
 import PropTypes from 'prop-types';
 
@@ -147,7 +147,7 @@ export default function DebuggerComponent({ pgAdmin, selectedNodeInfo, panelId,
           }
         });
       }
-    } catch (e) {
+    } catch {
       alert(xhr);
       pgAdmin.Browser.notifier.alert(
         gettext('Debugger Error'),
@@ -1083,6 +1083,7 @@ export default function DebuggerComponent({ pgAdmin, selectedNodeInfo, panelId,
       node_name: retrieveNodeName(selectedNodeInfo),
     },
     preferences: preferences,
+    containerRef: containerRef,
   }), [preferences]);
 
   // Define the debugger layout components such as DebuggerEditor to show queries and
