@@ -2,7 +2,7 @@
 #
 # pgAdmin 4 - PostgreSQL Tools
 #
-# Copyright (C) 2013 - 2023, The pgAdmin Development Team
+# Copyright (C) 2013 - 2024, The pgAdmin Development Team
 # This software is released under the PostgreSQL Licence
 #
 ##########################################################################
@@ -482,7 +482,7 @@ class TableCommand(GridCommand):
         """
 
         # Fetch the primary keys for the table
-        pk_names, primary_keys = self.get_primary_keys(default_conn)
+        _, primary_keys = self.get_primary_keys(default_conn)
 
         # Fetch OIDs status
         has_oids = self.has_oids(default_conn)
