@@ -13,7 +13,7 @@ import {genericBeforeEach, getCreateView, getEditView, getPropertiesView} from '
 
 describe('EventTriggerSchema', ()=>{
 
-  let schemaObj = new EventTriggerSchema(
+  const createSchemaObj = () => new EventTriggerSchema(
     {
       role: ()=>[],
       function_names: ()=>[],
@@ -22,26 +22,24 @@ describe('EventTriggerSchema', ()=>{
       eventowner: 'postgres'
     }
   );
+  let schemaObj = createSchemaObj();
   let getInitData = ()=>Promise.resolve({});
 
 
-
-
-
   beforeEach(()=>{
     genericBeforeEach();
   });
 
   it('create', async ()=>{
-    await getCreateView(schemaObj);
+    await getCreateView(createSchemaObj());
   });
 
   it('edit', async ()=>{
-    await getEditView(schemaObj, getInitData);
+    await getEditView(createSchemaObj(), getInitData);
   });
 
   it('properties', async ()=>{
-    await getPropertiesView(schemaObj, getInitData);
+    await getPropertiesView(createSchemaObj(), getInitData);
   });
 
   it('validate', ()=>{
