@@ -30,29 +30,24 @@ class SchemaInColl extends BaseUISchema {
 }
 
 describe('MembershipSchema', ()=>{
-
-  let schemaObj = new MembershipSchema(
-    ()=>[]);
+  const createSchemaObj = () => new MembershipSchema(()=>[]);
+  let schemaObj = createSchemaObj();
   let getInitData = ()=>Promise.resolve({});
 
-
-
-
-
   beforeEach(()=>{
     genericBeforeEach();
   });
 
   it('create', async ()=>{
-    await getCreateView(schemaObj);
+    await getCreateView(createSchemaObj());
   });
 
   it('edit', async ()=>{
-    await getEditView(schemaObj, getInitData);
+    await getEditView(createSchemaObj(), getInitData);
   });
 
   it('properties', async ()=>{
-    await getPropertiesView(schemaObj, getInitData);
+    await getPropertiesView(createSchemaObj(), getInitData);
   });
 
   it('MembershipMemberSchema', async ()=>{
